@@ -28,14 +28,14 @@ class BotGmailPlugin:
         self.gmail_service = None
         self.scopes = ['https://www.googleapis.com/auth/gmail.modify']
 
-        # The file token.json stores the user's access and refresh tokens, and is
+        # The file token_gmail.json stores the user's access and refresh tokens, and is
         # created automatically when the authorization flow completes for the first
         # time.
         credentials_dir = os.path.abspath(os.path.dirname(credentials_file_path))
 
-        if os.path.exists(os.path.join(credentials_dir, 'token.json')):
+        if os.path.exists(os.path.join(credentials_dir, 'token_gmail.json')):
             self.creds = Credentials.from_authorized_user_file(
-                os.path.join(credentials_dir, 'token.json'), self.scopes)
+                os.path.join(credentials_dir, 'token_gmail.json'), self.scopes)
         # If there are no (valid) credentials available, let the user log in.
         if not self.creds or not self.creds.valid:
             if self.creds and self.creds.expired and self.creds.refresh_token:
@@ -45,7 +45,7 @@ class BotGmailPlugin:
                     os.path.abspath(credentials_file_path), self.scopes)
                 self.creds = flow.run_local_server(port=0)
             # Save the credentials for the next run
-            with open(os.path.join(credentials_dir, 'token.json'), 'w') as token:
+            with open(os.path.join(credentials_dir, 'token_gmail.json'), 'w') as token:
                 token.write(self.creds.to_json())
 
         self.gmail_service = build('gmail', 'v1', credentials=self.creds)
@@ -102,7 +102,7 @@ class BotGmailPlugin:
                 return []
 
     def send_message(self, subject: str, text_content: str, to_addrs: List[str], cc_addrs: List[str] = None,
-                     bcc_addrs: List[str] = None, attachments: List[str] = None) -> None:
+                     bcc_addrs: List[str] = None, attachments: List[str] = None, use_html: bool = False) -> None:
         """
         Send a new email message.
 
@@ -114,15 +114,17 @@ class BotGmailPlugin:
             bcc_addrs (List[str], optional): The list of email addresses that will receive the message as BCC.
             attachments (List[str], optional): The list with the paths of the files that will be sent
                 as attachments.
+            use_html (bool): The boolean value when you want to use body in html format.
         """
-        new_message = self.__build_message(text_content, to_addrs, cc_addrs, bcc_addrs, attachments)
+        new_message = self.__build_message(text_content, to_addrs, cc_addrs, bcc_addrs, attachments, use_html)
         new_message["Subject"] = subject
         message = {'raw': base64.urlsafe_b64encode(new_message.as_bytes()).decode()}
 
         self.gmail_service.users().messages().send(userId="me", body=message).execute()
 
     def reply(self, msg: BotGmailMessage, text_content: str, attachments: List[str] = None,
-              to_addrs: List[str] = None, cc_addrs: List[str] = None, bcc_addrs: List[str] = None) -> None:
+              to_addrs: List[str] = None, cc_addrs: List[str] = None, bcc_addrs: List[str] = None,
+              use_html: bool = False) -> None:
         """
         Reply a received email message.
 
@@ -134,9 +136,10 @@ class BotGmailPlugin:
             to_addrs (List[str], optional): The list of email addresses that will receive the message.
             cc_addrs (List[str], optional): The list of email addresses that will receive the message as CC.
             bcc_addrs (List[str], optional): The list of email addresses that will receive the message as BCC.
+            use_html (bool): The boolean value when you want to use body in html format.
         """
         to = to_addrs or [msg.from_]
-        reply_msg = self.__build_message(text_content, to, cc_addrs, bcc_addrs, attachments)
+        reply_msg = self.__build_message(text_content, to, cc_addrs, bcc_addrs, attachments, use_html)
         reply_msg["References"] = reply_msg["In-Reply-To"] = msg.headers.get('message-id')[0]
         reply_msg["Subject"] = "Re: " + msg.subject
 
@@ -145,7 +148,8 @@ class BotGmailPlugin:
 
         self.gmail_service.users().messages().send(userId="me", body=message).execute()
 
-    def reply_to_all(self, msg: BotGmailMessage, text_content: str, attachments: List[str] = None) -> None:
+    def reply_to_all(self, msg: BotGmailMessage, text_content: str, attachments: List[str] = None,
+                     use_html: bool = False) -> None:
         """
         Replies to all email addresses included in the original message.
 
@@ -154,14 +158,15 @@ class BotGmailPlugin:
             text_content (str): The content of the email body.
             attachments (List[str], optional): The list with the paths of the files that will be sent
                 as attachments.
+            use_html (bool): The boolean value when you want to use body in html format.
         """
         emails_addrs = list(msg.to) + list(msg.cc)
         to = [msg.from_]
         cc = [addr for addr in emails_addrs if addr != self.user_email]
-        self.reply(msg, text_content, attachments, to, cc)
+        self.reply(msg, text_content, attachments, to, cc, use_html=use_html)
 
     def forward(self, msg: BotGmailMessage, to_addrs: List[str], cc_addrs: List[str] = None,
-                bcc_addrs: List[str] = None, include_attachments=True) -> None:
+                bcc_addrs: List[str] = None, include_attachments=True, use_html: bool = False) -> None:
         """
         Forward a received email message.
 
@@ -171,8 +176,9 @@ class BotGmailPlugin:
             cc_addrs (List[str], optional): The list of email addresses that will receive the message as CC.
             bcc_addrs (List[str], optional): The list of email addresses that will receive the message as BCC.
             include_attachments (boolean, optional): Include attachments from the original message.
+            use_html (bool): The boolean value when you want to use body in html format.
         """
-        forwarded_message = self.__build_message(msg.text, to_addrs, cc_addrs, bcc_addrs, is_forwarded=True)
+        forwarded_message = self.__build_message(msg.text, to_addrs, cc_addrs, bcc_addrs, is_forwarded=True, use_html=use_html)
         forwarded_message["Subject"] = "Fwd: " + msg.subject
         if include_attachments:
             for part in msg.attachments:
@@ -327,7 +333,7 @@ class BotGmailPlugin:
 
     def __build_message(self, text_content: str, to_addrs: List[str], cc_addrs: List[str] = None,
                         bcc_addrs: List[str] = None, attachments: List[str] = None,
-                        is_forwarded=False) -> MIMEMultipart:
+                        use_html=False, is_forwarded=False) -> MIMEMultipart:
         message = MIMEMultipart()
         message["From"] = self.user_email
 
@@ -343,7 +349,10 @@ class BotGmailPlugin:
             message["Bcc"] = bcc
 
         # Add body to email
-        text_message = MIMEText(text_content, "plain")
+        if use_html:
+            text_message = MIMEText(text_content, "html")
+        else:
+            text_message = MIMEText(text_content, "plain")
         message.attach(text_message)
 
         if is_forwarded:
